@@ -9,7 +9,14 @@ from matplotlib.axes import Axes
 from matplotlib.patches import Rectangle
 
 from pyretailscience.plots import bar
-from pyretailscience.style import graph_utils as gu
+from pyretailscience.plots.styles import graph_utils as gu
+
+
+@pytest.fixture(autouse=True)
+def cleanup_figures():
+    """Clean up matplotlib figures after each test."""
+    yield
+    plt.close("all")
 
 
 @pytest.fixture
@@ -34,17 +41,17 @@ def _mock_color_generators(mocker):
     """Mock the color generators for single and multi color maps."""
     single_color_gen = cycle(["#FF0000"])  # Mocked single-color generator (e.g., red)
     multi_color_gen = cycle(["#FF0000", "#00FF00", "#0000FF"])  # Mocked multi-color generator
-    mocker.patch("pyretailscience.style.tailwind.get_single_color_cmap", return_value=single_color_gen)
-    mocker.patch("pyretailscience.style.tailwind.get_multi_color_cmap", return_value=multi_color_gen)
+    mocker.patch("pyretailscience.plots.styles.tailwind.get_single_color_cmap", return_value=single_color_gen)
+    mocker.patch("pyretailscience.plots.styles.tailwind.get_multi_color_cmap", return_value=multi_color_gen)
 
 
 @pytest.fixture
 def _mock_gu_functions(mocker):
     """Mock the standard graph utilities functions."""
-    mocker.patch("pyretailscience.style.graph_utils.standard_graph_styles", side_effect=lambda ax, **kwargs: ax)
-    mocker.patch("pyretailscience.style.graph_utils.standard_tick_styles", side_effect=lambda ax: ax)
-    mocker.patch("pyretailscience.style.graph_utils.add_source_text", side_effect=lambda ax, source_text: ax)
-    mocker.patch("pyretailscience.style.graph_utils.apply_hatches", side_effect=lambda ax, num_segments: ax)
+    mocker.patch("pyretailscience.plots.styles.graph_utils.standard_graph_styles", side_effect=lambda ax, **kwargs: ax)
+    mocker.patch("pyretailscience.plots.styles.graph_utils.standard_tick_styles", side_effect=lambda ax: ax)
+    mocker.patch("pyretailscience.plots.styles.graph_utils.add_source_text", side_effect=lambda ax, source_text: ax)
+    mocker.patch("pyretailscience.plots.styles.graph_utils.apply_hatches", side_effect=lambda ax, num_segments: ax)
 
 
 @pytest.mark.usefixtures("_mock_color_generators", "_mock_gu_functions")
@@ -434,6 +441,9 @@ def test_default_value_col_handling(sample_series):
 
     assert isinstance(result_ax, Axes)
     assert len(result_ax.patches) == expected_num_patches
+    _, legend_labels = result_ax.get_legend_handles_labels()
+    assert legend_labels, "Expected legend labels but found none"
+    assert legend_labels == ["Value"], f"Expected legend label to be 'Value', got {legend_labels}"
 
 
 @pytest.mark.usefixtures("_mock_color_generators", "_mock_gu_functions")
@@ -497,12 +507,11 @@ def test_percentage_by_bar_group_with_negative_values():
             x_col="product",
             data_label_format="percentage_by_bar_group",
         )
-    plt.close("all")
 
 
 @pytest.mark.usefixtures("_mock_color_generators", "_mock_gu_functions")
 def test_percentage_by_bar_group_with_zero_group_total():
-    """Test percentage_by_bar_group with zero group totals and suppress the warning."""
+    """Test percentage_by_bar_group with zero group totals and verify warning is emitted."""
     df = pd.DataFrame({"product": ["A", "B"], "sales": [0, 0]})
 
     with pytest.warns(UserWarning, match="Division by zero detected"):
@@ -515,4 +524,3 @@ def test_percentage_by_bar_group_with_zero_group_total():
 
     labels = [t.get_text() for t in result_ax.texts]
     assert all(label == "" for label in labels)  # Should all be empty due to division by zero
-    plt.close("all")
